@@ -14,8 +14,8 @@ import gzip
 import tarfile
 import pickle
 import tempfile
-import indelpost
 
+from .indelpost import Variant, VariantAlignment
 from .common import log, GRange, AldyException, script_path, Timing, chr_prefix
 from .gene import Gene, CNConfigType
 from .coverage import Coverage
@@ -349,7 +349,8 @@ class Sample:
                 print(self.gene._lookup_seq, end="", file=f)
                 sz = sam.get_reference_length(rname)
                 print("N" * (sz - self.gene._lookup_range[1]), file=f)
-            os.system("samtools faidx " + reference)
+            with open(f"{reference}.fai", "w") as f:
+                print(rname, sz, len(rname) + 2, sz, sz + 1, sep="\t", file=f)
         ref = pysam.FastaFile(reference)  # type: ignore
 
         prev_indel = None
@@ -367,7 +368,7 @@ class Sample:
                 o = self.gene[p]
                 o1, o2 = o, o + op[3:]
 
-            v = indelpost.Variant(rname, p + 1, o1, o2, ref)  # type: ignore
+            v = Variant(rname, p + 1, o1, o2, ref)  # type: ignore
 
             if long_reads:
                 # Speed-up: just generate equivalent indels, no need for the realignment
@@ -383,7 +384,7 @@ class Sample:
                         self._indel_sites_eqs[np, no] = (pos, op)
                 continue
 
-            valn = indelpost.VariantAlignment(  # type: ignore
+            valn = VariantAlignment(  # type: ignore
                 v,
                 sam,
                 mapping_quality_threshold=self.profile.min_mapq,
@@ -696,7 +697,7 @@ class Sample:
                     continue
 
                 seq = read.query_sequence
-                qual = read.query_qualities
+                qual = read.query_qualities if read.query_qualities else [40] * len(seq)
                 if self._index:
                     # Split reads
                     pieces = []
